Balder Decorators API
*********************

This is the api documentation of all available balder decorators.


Decorator `@balder.connect(..)`
===============================

.. autofunction:: balder.connect


Decorator `@balder.fixture(..)`
===============================

.. autofunction:: balder.fixture


Decorator `@balder.for_vdevice(..)`
===================================

.. autofunction:: balder.for_vdevice


Decorator `@balder.covered_by(..)`
==================================

.. autofunction:: balder.covered_by


Decorator `@balder.insert_into_tree(..)`
========================================

.. autofunction:: balder.insert_into_tree
